package com.njyunzhi.servsummary.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.servsummary.common.BaseController;
import com.njyunzhi.servsummary.common.Constants;
import com.njyunzhi.servsummary.common.ResponseBean;

import java.util.List;

import com.njyunzhi.servsummary.common.StringUtils;
import com.njyunzhi.servsummary.entity.TaOssBucket;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.servsummary.entity.TaContcat;
import com.njyunzhi.servsummary.service.TaContcatService;

/**
 * 联系人;(ta_contcat)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-11-22
 */
@Api(tags = "联系人对象功能接口")
@RestController
@RequestMapping("/")
public class TaContcatController extends BaseController {

    @Autowired
    private TaContcatService taContcatService;

    /**
     * 通过ID查询单条数据
     *
     * @param userId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taContcat/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taContcatService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taContcat")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("名称") @RequestParam(value = "name", required = false) String name,
                             @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone,
                             @ApiParam("状态") @RequestParam(value = "status", required = false) Integer status) throws Exception {

        IPage<TaContcat> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaContcat> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.eq(null != status, "status", status);
        queryWrapper.like(!StringUtils.isEmpty(name), "name)", name);
        queryWrapper.like(!StringUtils.isEmpty(name), "phone", phone);
        queryWrapper.orderByDesc("create_date");
        IPage<TaContcat> result = taContcatService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param taContcat 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taContcat")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaContcat taContcat) throws Exception {
        if (StringUtils.isEmpty(taContcat.getName())) {
            return ResponseBean.error("名称不能为空");
        }

        TaContcat exist = taContcatService.getExistBy("name", taContcat.getName(), false, true);
        if (exist != null) {
            return ResponseBean.error("名称已存在");
        }

        taContcatService.save(taContcat);
        return ResponseBean.success(taContcat);
    }

    /**
     * 更新数据
     *
     * @param taContcat 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taContcat/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaContcat taContcat,
                             @ApiParam("对象ID") @PathVariable String id) throws Exception {
        taContcat.setUserId(id);

        if (StringUtils.isEmpty(taContcat.getName())) {
            return ResponseBean.error("名称不能为空");
        }

        TaContcat exist = taContcatService.getExistBy("name", taContcat.getName(), false, true);
        if (exist != null && !exist.getUserId().equals(id)) {
            return ResponseBean.error("名称已存在");
        }

        taContcatService.updateById(taContcat);
        return ResponseBean.success(taContcat);
    }

    /**
     * 通过主键删除数据
     *
     * @param userId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taContcat/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taContcatService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}